@@ -5,7 +5,7 @@ __author__    = 'Bram Hendrickx'
 __copyright__ = 'Copyright 2016 Bram Hendrickx'
 __license__   = 'Eclipse Public License - v 1.0 (http://www.eclipse.org/legal/epl-v10.html)'
 
-Original script by Bram Hendrickx. https://github.com/jpmens/mqttwarn/blob/master/services/ifttt.py
+Original script by Bram Hendrickx. https://github.com/jpmens/mqttwarn/blob/main/mqttwarn/services/ifttt.py
 Modified to work with notify-me app for Alexa. http://www.thomptronics.com/notify-me
 """
 
@@ -29,12 +29,13 @@ def plugin(srv, item):
             "accessCode": item.addrs[0]
         })
 
-        requests.post(url="https://api.notifymyecho.com/v1/NotifyMe", data=body)
+        response = requests.post(url="https://api.notifymyecho.com/v1/NotifyMe", data=body)
+        response.raise_for_status()
 
         srv.logging.debug("Successfully sent to NotifyMe service.")
 
     except Exception as e:
-        srv.logging.warning("Failed to send message to NotifyMe service." % e)
+        srv.logging.warning("Failed to send message to NotifyMe service: %s" % e)
         return False
 
     return True
